World coastlines at medium and fine-scale resolution
data(coastlineWorldMedium, package="ocedata")
data(coastlineWorldFine, package="ocedata")These datasets are analogous to coastlineWorld in
the Oce package, but they are of finer resolution; a comparison table
follows.
coastlineWorld is a coarse resolution 1:110M (with 10,696
points), suitable for world-scale plots plotted at a small size, e.g.
inset diagrams
coastlineWorldMedium resolution 1:50M (with 100,954 points),
suitable for world- or basin-scale plots
coastlineWorldFine resolution 1:10M (with 552,670 points),
suitable for shelf-scale plots
The documentation for coastline-class in the Oce package
explains the structure of coastline objects and discusses functions that
deal with them.
The maps package provides a database named world
that has 27221 points, putting it intermediate between the Oce default and
coarse versions.